"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const contracts_test_utils_1 = require("@0x/contracts-test-utils");
const order_utils_1 = require("@0x/order-utils");
const utils_1 = require("@0x/utils");
const stopLimitDataEncoder = utils_1.AbiEncoder.create([
    { name: 'oracle', type: 'address' },
    { name: 'minPrice', type: 'int256' },
    { name: 'maxPrice', type: 'int256' },
]);
const stopLimitMethodEncoder = utils_1.AbiEncoder.createMethod('checkStopLimit', [{ name: 'stopLimitData', type: 'bytes' }]);
/**
 * Encodes the given stop limit data parameters into the bytes format expected by the
 * ChainlinkStopLimit contract.
 */
function encodeChainlinkStopLimitData(params) {
    return stopLimitDataEncoder.encode(params);
}
exports.encodeChainlinkStopLimitData = encodeChainlinkStopLimitData;
/**
 * Encodes the given stop limit data parameters into StaticCall asset data so that it can be used
 * in a 0x order.
 */
function encodeStopLimitStaticCallData(chainlinkStopLimitAddress, params) {
    const staticCallData = stopLimitMethodEncoder.encode({
        stopLimitData: encodeChainlinkStopLimitData(params),
    });
    return order_utils_1.assetDataUtils.encodeStaticCallAssetData(chainlinkStopLimitAddress, staticCallData, contracts_test_utils_1.constants.KECCAK256_NULL);
}
exports.encodeStopLimitStaticCallData = encodeStopLimitStaticCallData;
/**
 * Decodes stop limit data parameters from the bytes format expected by the ChainlinkStopLimit contract.
 */
function decodeChainlinkStopLimitData(stopLimitData) {
    return stopLimitDataEncoder.decode(stopLimitData);
}
exports.decodeChainlinkStopLimitData = decodeChainlinkStopLimitData;
/**
 * Decodes stop limit data parameters from stop limit StaticCall asset data.
 */
function decodeStopLimitStaticCallData(assetData) {
    // tslint:disable-next-line:no-unnecessary-type-assertion
    const { staticCallData } = order_utils_1.assetDataUtils.decodeAssetDataOrThrow(assetData);
    const stopLimitData = stopLimitMethodEncoder.strictDecode(staticCallData);
    return decodeChainlinkStopLimitData(stopLimitData);
}
exports.decodeStopLimitStaticCallData = decodeStopLimitStaticCallData;
//# sourceMappingURL=chainlink_utils.js.map